@@ -19,68 +19,74 @@ class KnowledgeGraphCaller(CallerBase):
         # 导入数据
         self.app_id = app_id
         base_url = Config.base_url
-        self.data_load_url = '{}:18811/xeonKgDal/{}/importJson'.format(base_url, app_id)
+        self.data_load_url = '{}/xeonKgDal/{}/importJson'.format(base_url, app_id)
         # 触发异步训练
-        self.trigger_train_url = '{}:18811/xeonKgDal/{}/ftTrainTrigger?env=sandbox'.format(base_url, app_id)
+        self.trigger_train_url = '{}/xeonKgDal/{}/ftTrainTrigger?env=sandbox'.format(base_url, app_id)
         # 通知出话层更新数据
-        self.sync_data_url = '{}:13508/api/v1/kbqa/syncData?appid={}'.format(base_url, app_id)
+        self.sync_data_url = '{}/api/v1/kbqa/syncData?appid={}'.format(base_url, app_id)
         # 线下数据同步到线上
-        self.sync_sandbox_url = '{}:18811/xeonKgDal/{}/synchronizeSandbox'.format(base_url, app_id)
+        self.sync_sandbox_url = '{}/xeonKgDal/{}/synchronizeSandbox'.format(base_url, app_id)
         # 预测出话接口
-        self.predict_url = '{}:13508/api/v1/kbqa'.format(base_url)
+        self.predict_url = '{}/api/v1/kbqa'.format(base_url)
         # 获取训练结果
-        self.train_status_url = '{}:18811/xeonKgDal/syncHandler/{}/getSyncRecord'.format(base_url, app_id)
+        self.train_status_url = '{}/xeonKgDal/syncHandler/{}/getSyncRecord'.format(base_url, app_id)
 
-        self.file_load_url = '{}:18811/xeonKgDal/{}/import/all'.format(base_url, app_id)
+        self.file_load_url = '{}/xeonKgDal/{}/import/all'.format(base_url, app_id)
+        self.new_file_load_url = '{}/xeonKgDal/{}/import/all/v1'.format(base_url, app_id)
         # 检查实体是否重复
         self.check_entity_repeat_url \
-            = '{}:18811/xeonKgDal/entityManager/{}/checkRepeat/entity?entityName={}&entityId=&entityType=1'
+            = '{}/xeonKgDal/entityManager/{}/checkRepeat/entity?entityName={}&entityId=&entityType=1'
         # 获取实体 app_id, parent_entity_id, keyword
         self.load_entity_url \
-            = '{}:18811/xeonKgDal/entityProfile/{}/showEntityProfileDetail/{}?page=1&entityListKeyword={}'
+            = '{}/xeonKgDal/entityProfile/{}/showEntityProfileDetail/{}?page=1&entityListKeyword={}'
         # 新增一级实体
-        self.add_entity_url = '{}:18811/xeonKgDal/entityManager/{}/addEntity/root'.format(base_url, app_id)
+        self.add_entity_url = '{}/xeonKgDal/entityManager/{}/addEntity/root'.format(base_url, app_id)
         # 获取属性
-        self.load_property_url = '{}:18811/xeonKgDal/{}/property/allCommon?page=1&keyword={}'
+        self.load_property_url = '{}/xeonKgDal/{}/property/allCommon?page=1&keyword={}'
         # 新增屬性
-        self.add_property_url = '{}:18811/xeonKgDal/{}/property'.format(base_url, app_id)
+        self.add_property_url = '{}/xeonKgDal/{}/property'.format(base_url, app_id)
         # 查询属性值
-        self.load_relation_url = '{}:18811/xeonKgDal/relation/{}/getDataOverViewRelationByRootEntity/{}?page=1&limit=20&entityListKeyword='
+        self.load_relation_url = '{}/xeonKgDal/relation/{}/getDataOverViewRelationByRootEntity/{}?page=1&limit=20&entityListKeyword='
         # 新增属性值
-        self.add_relation_url = '{}:18811/xeonKgDal/relation/{}/addRelation'.format(base_url, app_id)
+        self.add_relation_url = '{}/xeonKgDal/relation/{}/addRelation'.format(base_url, app_id)
         # 更新属性值
-        self.update_relation_url = '{}:18811/xeonKgDal/relation/{}/updateRelation'.format(base_url, app_id)
+        self.update_relation_url = '{}/xeonKgDal/relation/{}/updateRelation'.format(base_url, app_id)
         # 更新实体简介
-        self.update_entity_intro_url = '{}:18811/xeonKgDal/entityProfile/{}/addEntityProfile/{}'
+        self.update_entity_intro_url = '{}/xeonKgDal/entityProfile/{}/addEntityProfile/{}'
         # 更新属性简介
-        self.update_property_intro_url = '{}:18811/xeonKgDal/{}/property/desc'.format(base_url, app_id)
+        self.update_property_intro_url = '{}/xeonKgDal/{}/property/desc'.format(base_url, app_id)
         # 添加属性语料
-        self.add_property_corpus_url = '{}:18811/xeonKgDal/{}/property/{}'
+        self.add_property_corpus_url = '{}/xeonKgDal/{}/property/{}'
+        # 查询特殊属性
+        self.load_extra_property_url = '{}/xeonKgDal/extraPropertyManager/{}/getAll?page=1&keyword={}&limit=10'
+        # 更新特殊属性
+        self.update_extra_property_url = '{}/xeonKgDal/extraPropertyManager/{}/update'.format(base_url, app_id)
+
         # 词库 新增同义词 实体/属性
-        self.wordbank_add_url = '{}:18811/xeonKgDal/synonym/{}/addSynonym'.format(base_url, app_id) + "/{}?type={}"
+        self.wordbank_add_url = '{}/xeonKgDal/synonym/{}/addSynonym'.format(base_url, app_id) + "/{}?type={}"
         # 词库 更新同义词 实体/属性
-        self.wordbank_update_url = '{}:18811/xeonKgDal/synonym/{}/updateSynonym'.format(base_url,
-                                                                                        app_id) + "/{}?type={}"
+        self.wordbank_update_url = '{}/xeonKgDal/synonym/{}/updateSynonym'.format(base_url,
+                                                                                  app_id) + "/{}?type={}"
         # 词库 删除同义词 实体/属性
-        self.wordbank_delete_url = '{}:18811/xeonKgDal/synonym/{}/deleteSynonym'.format(base_url,
-                                                                                        app_id) + "/{}?type={}"
+        self.wordbank_delete_url = '{}/xeonKgDal/synonym/{}/deleteSynonym'.format(base_url,
+                                                                                  app_id) + "/{}?type={}"
         # 词库 查询同义词 实体/属性
-        self.wordbank_get_url = '{}:18811/xeonKgDal/synonym/{}/showSynonym'.format(base_url,
-                                                                                   app_id) + "?show=matchId&type={}&object_id={}"
+        self.wordbank_get_url = '{}/xeonKgDal/synonym/{}/showSynonym'.format(base_url,
+                                                                             app_id) + "?show=matchId&type={}&object_id={}"
 
         # 词库 新增值同义词
-        self.wordbank_value_add_url = '{}:18811/xeonKgDal/propertyKeyword/{}/addKeywordSynonym'.format(base_url, app_id)
+        self.wordbank_value_add_url = '{}/xeonKgDal/propertyKeyword/{}/addKeywordSynonym'.format(base_url, app_id)
         # 词库 更新值同义词
-        self.wordbank_value_update_url = '{}:18811/xeonKgDal/propertyKeyword/{}/updateKeywordSynonym'.format(base_url,
-                                                                                                             app_id)
+        self.wordbank_value_update_url = '{}/xeonKgDal/propertyKeyword/{}/updateKeywordSynonym'.format(base_url,
+                                                                                                       app_id)
         # 词库 删除同义词
-        self.wordbank_value_delete_url = '{}:18811/xeonKgDal/propertyKeyword/{}/deleteKeywordSynonym'.format(base_url,
-                                                                                                             app_id)
+        self.wordbank_value_delete_url = '{}/xeonKgDal/propertyKeyword/{}/deleteKeywordSynonym'.format(base_url,
+                                                                                                       app_id)
         # 词库 查询值同义词
-        self.wordbank_value_get_url = '{}:18811/xeonKgDal/propertyKeyword/{}?target=getAll'.format(base_url, app_id)
+        self.wordbank_value_get_url = '{}/xeonKgDal/propertyKeyword/{}?target=getAll'.format(base_url, app_id)
 
         # 初始知识库
-        self.init_url = '{}:18811/xeonKgDal/property/{}/initialProperty'.format(base_url, app_id)
+        self.init_url = '{}/xeonKgDal/property/{}/initialProperty'.format(base_url, app_id)
 
     def init_data(self):
         """
@@ -114,14 +120,17 @@ class KnowledgeGraphCaller(CallerBase):
             msg = "kg: 上传数据失败， 原因: Exception When POST '{}' : {}".format(self.data_load_url, traceback.format_exc())
             raise BfEngineException(ErrorCode.kg_import_error, msg)
 
-    def load_file(self, file_path: str):
+    def load_file(self, file_path: str, use_old):
         """
         加载文件格式训练数据
         :param file_path: kg数据文件路径
         """
         try:
             files = {"file": (open(file_path, 'rb'))}
-            response = requests.post(self.file_load_url, files=files)
+            file_load_url = self.new_file_load_url
+            if use_old is not None and use_old:
+                file_load_url = self.file_load_url
+            response = requests.post(file_load_url, files=files)
             if self._response_failed(response):
                 msg = "kg: 上传训练数据失败：原因: 上传数据接口异常。" + str(response.json()) if response is not None else ''
                 raise BfEngineException(ErrorCode.kg_import_error, msg)
@@ -210,8 +219,8 @@ class KnowledgeGraphCaller(CallerBase):
         :param online：线上 True 线下 False
         :return: 机器人回答
         """
-        answer = Answer('', 0)
-        if online:
+        answer = Answer(text='', score=0)
+        if online is None or online:
             env = "production"
         else:
             env = "sandbox"
@@ -232,7 +241,7 @@ class KnowledgeGraphCaller(CallerBase):
             else:
                 response_json = response.json()
                 if response_json.get('response'):
-                    answer = Answer(response_json.get('response'), response_json.get('score'))
+                    answer = Answer(text=response_json.get('response'), score=response_json.get('score'))
                 else:
                     pass
                     # logging.warning('kg: 预测为空 [{}]'.format(msg))
@@ -240,7 +249,7 @@ class KnowledgeGraphCaller(CallerBase):
             msg = "Exception When POST '{}' : {}".format(self.predict_url, traceback.format_exc())
             logging.error('kg: 对话失败， 原因: ' + msg)
         finally:
-            if not answer.value:
+            if not answer.text:
                 answer.value = Config.backfill_speech
                 answer.score = 60
             return answer
@@ -590,6 +599,40 @@ class KnowledgeGraphCaller(CallerBase):
             logging.error('kg: 新增属性语料失败， 原因：' + msg)
             return False
 
+    def update_property_speech(self, property, speech):
+        """
+        新增属性简介
+        :property: 属性
+        :corpus: 新增的语料
+        :return: 结果
+        """
+        if not speech:
+            return True
+        param = {
+            "name": property.get('name'),
+            "corpus": property.get('corpus'),
+            "category": property.get('category'),
+            "unit": property.get('unit'),
+            "speech": "{\"answer\":\"" + speech + "\",\"property\":{\"dimension_id_list\":[]}}",
+            "parentId": -1,
+            "slotInfo": {
+                "url": "",
+                "slotList": []
+            },
+            "speechType": str(property.get('speechType'))
+        }
+        try:
+            response = requests.put(
+                url=self.add_property_corpus_url.format(Config.base_url, self.app_id, property.get('id')), json=param)
+            if self._response_failed(response):
+                logging.error("kg: 更新属性话术失败：原因: 接口异常。" + str(response.json()) if response is not None else '')
+            else:
+                return True
+        except Exception:
+            msg = "Exception When POST '{}' : {}".format(self.add_property_corpus_url, traceback.format_exc())
+            logging.error('kg: 更新属性话术失败，原因：' + msg)
+            return False
+
     def _get_wordbank_synonym(self, type, object_id):
         try:
             url = self.wordbank_get_url.format(type, object_id)
@@ -813,7 +856,7 @@ class KnowledgeGraphCaller(CallerBase):
         :return:
         """
         try:
-            property_object = self.load_entity(0, property_name)
+            property_object = self.load_property(property_name)
             if property_object is not None:
                 property_id = property_object['id']
                 return self._get_wordbank_synonym("property", property_id)
@@ -854,7 +897,7 @@ class KnowledgeGraphCaller(CallerBase):
         :return:
         """
         try:
-            response = requests.delete(url=self.wordbank_value_get_url)
+            response = requests.get(url=self.wordbank_value_get_url)
             if self._response_failed(response):
                 logging.error("kg: 查询值同义词失败：原因: 接口异常。" + str(response.text) if response is not None else '')
             else:
@@ -906,3 +949,108 @@ class KnowledgeGraphCaller(CallerBase):
         except Exception:
             msg = "Exception When POST '{}' : {}".format(self.wordbank_update_url, traceback.format_exc())
             logging.error('kg: 删除值同义词失败， 原因：' + msg)
+
+    def load_extra_property(self, property_name, entity_name):
+        """
+        获取实体
+        :property_name: 属性名称
+        :entity_name: 实体名称
+        :return: 结果
+        """
+        try:
+            response = requests.get(self.load_extra_property_url.format(Config.base_url, self.app_id, property_name))
+            if self._response_failed(response):
+                logging.error("kg: 获取特殊属性失败：原因: 接口异常。" + str(response.json()) if response is not None else '')
+            else:
+                response_json = response.json()
+                if response_json.get('data').get('result'):
+                    results = response.json().get('data').get('result')
+                    if results:
+                        for result in results:
+                            if result.get('entityName') == entity_name:
+                                return result
+                        return None
+                    else:
+                        return None
+                else:
+                    return None
+        except Exception:
+            msg = "Exception When GET '{}' : {}".format(self.load_property_url, traceback.format_exc())
+            logging.error('kg: 获取特殊属性失败， 原因：' + msg)
+            return None
+
+    def add_extra_property(self, property_id, entity_id, category, unit):
+        """
+        获取实体
+        :property_id: 属性id
+        :entity_id: 实体id
+        :category: 属性类型
+        :unit: 单位
+        :return: 结果
+        """
+        param = {
+            "propertyId": property_id,
+            "extraProperties": [{
+                "entityId": entity_id,
+                "category": category,
+                "unit": unit,
+                "speech": "{\"answer\":\"\",\"property\":{\"dimension_id_list\":[]}}",
+                "speechType": "201",
+                "extra_content": {}
+            }]
+        }
+        try:
+            response = requests.post(url=self.update_extra_property_url, json=param)
+            if self._response_failed(response):
+                logging.error("kg: 更新特殊属性失败：原因: 接口异常。" + str(response.json()) if response is not None else '')
+            else:
+                return True
+        except Exception:
+            msg = "Exception When POST '{}' : {}".format(self.update_extra_property_url, traceback.format_exc())
+            logging.error('kg: 更新特殊属性失败， 原因：' + msg)
+            return False
+
+    def update_extra_property(self, property_name, entity_name, category, unit):
+        """
+        获取实体
+        :property_name: 属性名称
+        :entity_name: 实体名称
+        :return: 结果
+        """
+        param = {
+            "propertyId": 0,
+            "extraProperties": [{
+                "entityId": 0,
+                "category": category,
+                "unit": unit,
+                "speech": "{\"answer\":\"\",\"property\":{\"dimension_id_list\":[]}}",
+                "speechType": "201",
+                "extra_content": {}
+            }]
+        }
+        try:
+            response = requests.get(self.load_extra_property_url.format(Config.base_url, self.app_id, property_name))
+            if self._response_failed(response):
+                logging.error("kg: 获取特殊属性失败：原因: 接口异常。" + str(response.json()) if response is not None else '')
+            else:
+                response_json = response.json()
+                if response_json.get('data').get('result'):
+                    results = response.json().get('data').get('result')
+                    if results:
+                        for result in results:
+                            if result.get('entityName') == entity_name:
+                                result['category'] = category
+                                result['unit'] = unit
+                                param['propertyId'] = result.get('propertyId')
+                                result['extra_content'] = result['extraContent']
+                                param['extraProperties'] = result
+                                response = requests.post(url=self.update_extra_property_url, json=param)
+                                if self._response_failed(response):
+                                    logging.error(
+                                        "kg: 更新特殊属性失败：原因: 接口异常。" + str(response.json()) if response is not None else '')
+                                    return False
+                return True
+        except Exception:
+            msg = "Exception When GET '{}' : {}".format(self.load_property_url, traceback.format_exc())
+            logging.error('kg: 获取特殊属性失败， 原因：' + msg)
+            return False
