@@ -696,8 +696,8 @@ class QACaller(CallerBase):
         answer_map = {};
         log.info(self.module + "开始")
         category_ids_list = self.get_all_sub_list(category_ids)
-        log.info(self.module + "子目录查询完毕")
-        self.get_all_sq_under_input_folders(category_ids_list, sq_list, sq_map, answer_map)
+        log.info(self.module + "子目录查询完毕"+str(category_ids_list))
+        self.get_all_sq_under_input_folders(sq_list, sq_map, answer_map)
         log.info(self.module + "sq获取完毕")
         converter = Converter('zh-hans')
         params = {"Text":converter.convert(user_inputs).lower(),'UniqueId':str(random.randint(100,10000)),"IsRelease": online,'Robot':self.app_id}
@@ -706,18 +706,17 @@ class QACaller(CallerBase):
         resp = requests.request("POST", self.get_predict_qa_list_url, headers=self.header, json=params).json()
         code = int(resp["code"])
         msg = str(resp["message"])
-        print(resp['data'])
+        log.info(resp['data'])
         if code != 0:
             raise BfEngineException(code=code, msg=msg)
         log.info(self.module + "预测结果获取完毕")
-        for match_sq in resp['data']:
-            if 'sqId' in match_sq and match_sq['sqId'] in sq_list:
-               match_sq['category_id'] = str(sq_map.get(match_sq['sqId']))
-               if(len(category_ids_list)>0) and match_sq['category_id'] in category_ids_list:
-                      similar_sq_result.append(match_sq)
-               else:
-                      similar_sq_result.append(match_sq)
+        self.process_predict_result(category_ids_list, resp, similar_sq_result, sq_list, sq_map)
         log.info(self.module + "结果处理完毕")
+        similar_sq_result = self.get_topn_result(answer_map, max_topn, similar_sq_result)
+        log.info(self.module + "返回结果")
+        return similar_sq_result
+
+    def get_topn_result(self, answer_map, max_topn, similar_sq_result):
         topn = int(max_topn)
         similar_sq_result = sorted(similar_sq_result, key=lambda x: x["score"], reverse=True)[:topn]
         for result_sq in similar_sq_result:
@@ -727,10 +726,18 @@ class QACaller(CallerBase):
             for ans in ans_resp_list:
                 ans_list.append(ans['answer'])
             result_sq['answer'] = ans_list
-        log.info(self.module + "返回结果")
         return similar_sq_result
 
-    def get_all_sq_under_input_folders(self, category_ids_list, sq_list, sq_map,answer_map):
+    def process_predict_result(self, category_ids_list, resp, similar_sq_result, sq_list, sq_map):
+        for match_sq in resp['data']:
+            if 'sqId' in match_sq and match_sq['sqId'] in sq_list:
+                match_sq['category_id'] = str(sq_map.get(match_sq['sqId']))
+                if (len(category_ids_list) > 0) and int(match_sq['category_id']) in category_ids_list:
+                    similar_sq_result.append(match_sq)
+                elif (len(category_ids_list) == 0):
+                    similar_sq_result.append(match_sq)
+
+    def get_all_sq_under_input_folders(self, sq_list, sq_map,answer_map):
         data = {"search": [{"keyword": "", "field": "sq"}],
                 "conditions": {"category": {"id_list": [], "logical_op": "and"}}}
         sq_resp = requests.post(self.search_faq_json_question_list_url, headers=self.header, json=data).json()
