@@ -6,6 +6,10 @@ from .intent_answering import IntentAnswering
 from .ner_parser import NERParser
 from .dialogue_act import DialogueAct
 from .config_manager import ConfigManager
+from .log_statistic import LogStatistic
+from .common_service import CommonService
+from .chat_service import ChatService
+from .skill_service import SkillService
 from .set import Set
 
 
@@ -25,3 +29,7 @@ class Bot:
         self.ner = NERParser(app_id, self.set, init_module)
         self.act = DialogueAct(app_id, self.set, init_module)
         self.config = ConfigManager(app_id, self.set, init_module)
+        self.statistic = LogStatistic(app_id, self.set, init_module)
+        self.common_service = CommonService(app_id, self.set, init_module)
+        self.chat = ChatService(app_id, self.set, init_module)
+        self.skill = SkillService(app_id, self.set, init_module)
