@@ -13,10 +13,13 @@ from ..core.module import Module
 from ..entity.exception import BfEngineException
 from ..logger import log
 from .task_engine import TaskEngine
+
 module_name_map = {
     "qa": "faq",
     "kg": "domain_kg",
     "te": "task_engine",
+    "chat": "chat",
+    "remote_skill": "remote_skill",
     "backfill": "backfill"
 }
 module_template = {
@@ -95,22 +98,14 @@ init_models = [
         "uid": "intent_model",
         "ccs_id": "",
         "name": "意图",
-        "url": "http://172.17.0.1:11035/predict",
+        "url": "http://172.17.0.1:9090//intent/predict",
         "method": "post",
         "category": "external",
         "request_body": {
-            "SessionId": "$.request.sessionId",
-            "Text": "$.request.body.text",
-            "Robot": "$.request.appId",
-            "IsRelease": True,
-            "UserId": "$.request.userId"
+            "text": "$.request.body.text",
         },
         "request_header": {
-            "X-locale": "zh-cn",
-            "app_id": "",
-            "user_id": "bf-engine-sdk",
-            "Authorization": "Bearer EMOTIBOTDEBUGGER",
-            "Accept": "application/json,text/plain, */*"
+            "app_id": ""
         },
         "app_id": ""
     }
@@ -120,10 +115,11 @@ init_args = [
         "uid": "intent_arg",
         "ccs_id": "",
         "name": "$intent",
-        "path": "$.model.意图.data[0].matchQuestion",
+        "path": "$.model.意图.data.text",
         "value": ""
     }
 ]
+append_modules = ["remote_skill", "chat", "backfill"]
 
 
 class ConfigGenerator:
@@ -225,7 +221,6 @@ class ConfigGenerator:
         }
 
 
-
 class DialogueManager(Module):
     """
     对话管理
@@ -235,7 +230,7 @@ class DialogueManager(Module):
         super().__init__(app_id, 'dm', set)
         self.app_id = app_id
         self.module_call_url = '{}/{}'.format(Config.base_url, Config.robot_url)
-        self.chat_url = '{}/{}?appId={}'.format(Config.base_url, Config.chat_url,app_id)
+        self.chat_url = '{}/{}?appId={}'.format(Config.base_url, Config.chat_url, app_id)
         self.caller = DialogueManagerCaller(app_id)
         tmp_dir = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
         self.default_dm_config_path = tmp_dir + "/data/default_dm.json"
@@ -275,7 +270,6 @@ class DialogueManager(Module):
             simple_phases = json.load(open(self.default_dm_config_path))
         return self.load(simple_phases)
 
-
     """
     根据传入参数生成出话配置
     """
@@ -318,9 +312,12 @@ class DialogueManager(Module):
 
         # 现在只有预置模型服务
         models = ConfigGenerator.get_init_models(self.app_id)
-        # 增加backfill模块
-        backfill_module_object = ConfigGenerator.get_module('backfill', self.app_id, self.module_call_url)
-        modules.append(backfill_module_object)
+        init_module_name_map = {}
+        # 增加预置的模块
+        for init_module in append_modules:
+            init_module_module_object = ConfigGenerator.get_module(init_module, self.app_id, self.module_call_url)
+            init_module_name_map[init_module] = init_module_module_object
+            modules.append(init_module_module_object)
 
         # current task for te
         init_phase = ConfigGenerator.get_phase()
@@ -376,23 +373,26 @@ class DialogueManager(Module):
                 task_engine_rewind_phase['thresholds'].append(threshold)
         workflow.append(task_engine_rewind_phase)
 
-        # 附加backfill出话模块
-        backfill_phase = ConfigGenerator.get_phase()
-        backfill_phase['phase_id'] = util.random_uuid()
-        backfill_phase['bots'] = modules
-        group = ConfigGenerator.get_phase_group()
-        group_name = util.random_uuid()
-        group['name'] = group_name
-        group['bots'].append(backfill_module_object['name'])
-        backfill_phase['group'].append(group)
-        backfill_dispatcher = ConfigGenerator.get_phase_dispatcher()
-        backfill_dispatcher['groups'].append(group_name)
-        backfill_phase['dispatcher']['dispatchers'].append(backfill_dispatcher)
-        backfill_phase['score_rules'].append(ConfigGenerator.get_score_rule(backfill_module_object['name'], 90))
-        workflow.append(backfill_phase)
+        # 附加预置模块
+        for init_module in append_modules:
+            append_phase = ConfigGenerator.get_phase()
+            append_phase['phase_id'] = util.random_uuid()
+            append_phase['bots'] = modules
+            group = ConfigGenerator.get_phase_group()
+            group_name = util.random_uuid()
+            group['name'] = group_name
+            group['bots'].append(init_module_name_map[init_module]['name'])
+            append_phase['group'].append(group)
+            backfill_dispatcher = ConfigGenerator.get_phase_dispatcher()
+            backfill_dispatcher['groups'].append(group_name)
+            append_phase['dispatcher']['dispatchers'].append(backfill_dispatcher)
+            if init_module == 'backfill':
+                append_phase['score_rules'].append(ConfigGenerator.get_score_rule(init_module_name_map[init_module]['name'], 90))
+            workflow.append(append_phase)
 
         return config
-    def qrcode(self,filePath:str=None):
+
+    def qrcode(self, filePath: str = None):
         if filePath:
             qr = qrcode.QRCode(
                 version=None,
@@ -407,6 +407,7 @@ class DialogueManager(Module):
         else:
             return
             # qrcode_terminal.draw(self.chat_url)
+
     def query(self, msg):
         try:
             answer = self.caller.call(msg)
